Functions with Tuples and Dictionaries Mixed-Up Code Questions
---------------------------------------------------------------

.. selectquestion:: Functions_Tups_Dictionaries_MixedUpCode_1_sq
   :fromid: Functions_Tups_Dictionaries_MixedUpCode_1_v2, Functions_Tups_Dictionaries_MixedUpCode_1_v2_ac
   :toggle: 


.. selectquestion:: Functions_Tups_Dictionaries_MixedUpCode_2_sq
   :fromid: Functions_Tups_Dictionaries_MixedUpCode_2, Functions_Tups_Dictionaries_MixedUpCode_2_ac
   :toggle: 


.. selectquestion:: Functions_Tups_Dictionaries_MixedUpCode_3_sq
   :fromid: Functions_Tups_Dictionaries_MixedUpCode_3, Functions_Tups_Dictionaries_MixedUpCode_3_ac
   :toggle: 


.. selectquestion:: Functions_Tups_Dictionaries_MixedUpCode_4_sq
   :fromid: Functions_Tups_Dictionaries_MixedUpCode_4, Functions_Tups_Dictionaries_MixedUpCode_4_ac
   :toggle: 


.. selectquestion:: Functions_Tups_Dictionaries_MixedUpCode_5_sq
   :fromid: Functions_Tups_Dictionaries_MixedUpCode_5, Functions_Tups_Dictionaries_MixedUpCode_5_ac
   :toggle: 
